@@ -18,9 +18,10 @@
 #include <netdb.h>
 
 #include <stdio.h>
+#include <string.h>
 
-#define Q_DIV
-#define Q_MUL
+#define Q_DIV(X) (X)
+#define Q_MUL(X) (X)
 #define DEV_QBSIZE DEV_BSIZE
 #define Q_CTL_V2
 #define CADR
